@@ -4,7 +4,7 @@ import datetime
 import time
 
 
-class HeartbeatManager():
+class HeartbeatManager:
     def __init__(self, kafka_heartbeat_producer: ProducerManager, heartbeat_interval, client_id):
         self.heartbeat_interval = heartbeat_interval
         self.client_id = client_id
@@ -19,8 +19,8 @@ class HeartbeatManager():
         date_ms = int(time.mktime(date.timetuple())) * 1000
 
         message_json = {"id": self.client_id, "alive": date_ms}
-        message = {"messages": message_json}
-        self.kafka_heartbeat_producer.send_messages(message)
+        messages = [{"message": message_json}]
+        self.kafka_heartbeat_producer.send_messages(messages)
 
     def stop(self):
         self.helper.stop_set_interval_thread()
